@@ -15,7 +15,8 @@ namelists = ("atm_in", "atm_modelio", "cpl_modelio", "drv_flds_in", "drv_in",
              "ocn_modelio", "rof_modelio", "user_nl_cam", "user_nl_clm",
              "user_nl_cpl", "user_nl_mosart", "user_nl_mpascice",
              "user_nl_mpaso", "wav_modelio", "iac_modelio", "docn_in",
-             "user_nl_docn", "user_nl_cice", "ice_in")
+             "user_nl_docn", "user_nl_cice", "ice_in", "user_nl_elm",
+             "user_nl_eam")
 
 xmlfiles = ("env_archive", "env_batch", "env_build", "env_case",
             "env_mach_pes", "env_mach_specific", "env_run", "env_workflow",
@@ -210,12 +211,12 @@ class PACEDB(App):
 
         from xml.parsers.expat import ExpatError
 
-        mgr = self.get_manager()
-        ret, fwds = mgr.run_command(cmd)
-
-        jsondata = fwds["data"]
-
         try:
+            mgr = self.get_manager()
+            ret, fwds = mgr.run_command(cmd)
+
+            jsondata = fwds["data"]
+
             xml = self.session.query(XMLInputs).filter_by(
                     expid=expid, name=name).first()
 
@@ -361,6 +362,10 @@ class PACEDB(App):
         if ext == ".zip" and len(items)==3:
             expid = int(items[2])
 
+            if self.session.query(E3SMexp.expid).filter_by(expid=expid).scalar() is None:
+                print("Warning: Expid, %d, does not exist in database." % expid)
+                return
+
             if not self.verify_db and self.create_expid_table:
 
                     try:
